#include "TaskWin.h"

TaskWin::TaskWin(PegRect rect, CPMainFrame * frame): CPModuleWindow(rect,0,0,frame)
{
	PegRect r = {8,64,151,210}; //size of the edit box
  	txtbox = new CPEditBox(r,0,FF_RECESSED|EF_EDIT|EF_WRAP,"", 20000); //create an edit box to show and edit the text for each day
  	txtbox->SetScrollMode(WSM_AUTOVSCROLL); //make vertical scrollbars appear when needed
	Add(txtbox); //add the edit box to the presentation, i had problems resizing so i used Add() instead of AddR()
	
	isStartUp=true; //everything is starting up
	isFullScreen=true; //the app starts in full screen mode
	
	CPReadMCSFile in("data", "Task3000", IMU_MCS_TypeMem); //creates a file to read data from

	if(in.FileExists()) //if the file exists it will populate the week[] array with data
 	    Read();
 	    
	DispBox(Sunday); //sets the edit box to show the default day
}    

void TaskWin::AddUI() //add the various day buttons
{
	PegTextButton* b = new PegTextButton(1,1, "S ", IDB_SUN,AF_ENABLED|TT_COPY);
	m_ui->AddToolbarButton(b);
	b = new PegTextButton(1,1, " M ", IDB_MON,AF_ENABLED|TT_COPY);
	m_ui->AddToolbarButton(b);
	b = new PegTextButton(1,1, " T ", IDB_TUES,AF_ENABLED|TT_COPY);
	m_ui->AddToolbarButton(b);
	b = new PegTextButton(1,1, " W ", IDB_WEND,AF_ENABLED|TT_COPY);
	m_ui->AddToolbarButton(b);
	b = new PegTextButton(1,1, " T ", IDB_THURS,AF_ENABLED|TT_COPY);
	m_ui->AddToolbarButton(b);
	b = new PegTextButton(1,1, " F ", IDB_FRI,AF_ENABLED|TT_COPY);
	m_ui->AddToolbarButton(b);
	b = new PegTextButton(1,1, " S", IDB_SAT,AF_ENABLED|TT_COPY);
	m_ui->AddToolbarButton(b);
	
}

void TaskWin::Draw()
{
    BeginDraw();
   	ClearScreen();
	DrawFrame();
	DrawChildren();
	
	if(isStartUp) //if everything is starting up, set the status bar to Sunday
	{
	    isStartUp=false;
	    Status("Sunday"); //this doesnt work in the constructor
	}
	    
	//text
	Locate(45,5,"Task 3000",true);
	Locate(15,16,"-Classpad Day Planner-");
    Locate(30,180,"By CrimsonCasio",true);
    
    EndDraw();
}

void TaskWin::DispBox(Day today) //sets the contense of the edit box to the current day's data
{
 	 myDay=today;
	 txtbox->DataSet(week[today]);
 	 txtbox->Draw();
}	    

void TaskWin::Locate(int x, int y, CPString text) //places text on the screen
{
    PegColor col;
	PegPoint p = {x,y};
	DrawTextR(p,text,col,PegTextThing::GetBasicFont()); 
}	

void TaskWin::Locate(int x, int y, CPString text, bool bold) // places text on the screen, allows for bold text
{
    PegColor col;
	PegPoint p = {x,y};
	if(bold)
		DrawTextR(p,text,col,PegTextThing::GetBoldFont()); 
	else
		DrawTextR(p,text,col,PegTextThing::GetBasicFont()); 
}	

void TaskWin::Status(CPString today) //sets the taskbar
{
    GetStatusBar()->SetTextField(1, today);
}    

void TaskWin::Write() //Writes data to the data file used by Task3000
{
	 CPWriteMCSFile out("data", "Task3000", IMU_MCS_TypeMem);
	 CPMEMFileHeader header("Task3000", "Tasks");
	 header.Write(out); //writes the header (the part that is displayed in the variable manager)
	 week[Sunday].Write(out);
  	 week[Monday].Write(out);
  	 week[Tuesday].Write(out);
  	 week[Wendsday].Write(out);
  	 week[Thursday].Write(out);
  	 week[Friday].Write(out);
  	 week[Saturday].Write(out);
  	 out.Realize(); // Writing actually beings after this
	 header.Write(out);
	 week[Sunday].Write(out);
  	 week[Monday].Write(out);
  	 week[Tuesday].Write(out);
  	 week[Wendsday].Write(out);
  	 week[Thursday].Write(out);
  	 week[Friday].Write(out);
  	 week[Saturday].Write(out);  
}    

void TaskWin::Read() //gets data from the data MCS data file used by Task3000
{
     CPReadMCSFile in("data", "Task3000", IMU_MCS_TypeMem);
     CPMEMFileHeader header("Task3000", "Tasks"); //reads the header
     header.Read(in);
	 week[Sunday].Read(in);
  	 week[Monday].Read(in);
  	 week[Tuesday].Read(in);
  	 week[Wendsday].Read(in);
  	 week[Thursday].Read(in);
  	 week[Friday].Read(in);
  	 week[Saturday].Read(in);
}  

SIGNED TaskWin::Message(const PegMessage &Mesg)
{
	switch(Mesg.wType)
    {
		case SIGNAL(IDB_SUN, PSF_CLICKED): //sets the day being viewed to Sunday
		{
		    week[myDay]= (txtbox->DataGet());
		    Status("Sunday");
			DispBox(Sunday);
			break;			
		}
		case SIGNAL(IDB_MON, PSF_CLICKED): //sets the day being viewed to Monday
  		{
  		    week[myDay]= (txtbox->DataGet());
  		    Status("Monday");
		 	DispBox(Monday);
			break;
		}
		case SIGNAL(IDB_TUES, PSF_CLICKED): //sets the day being viewed to Tuesday
  		{
  		    week[myDay]= (txtbox->DataGet());
  		    Status("Tuesday");
		 	DispBox(Tuesday);
			break;
		}
		case SIGNAL(IDB_WEND, PSF_CLICKED): //sets the day being viewed to Wendsday
  		{
  		    week[myDay]= (txtbox->DataGet());
  		    Status("Wendsday");
		 	DispBox(Wendsday);
			break;
		}
		case SIGNAL(IDB_THURS, PSF_CLICKED): //sets the day being viewed to Thursday
  		{
  		    week[myDay]= (txtbox->DataGet());
  		    Status("Thursday");
		 	DispBox(Thursday);
			break;
		}
		case SIGNAL(IDB_FRI, PSF_CLICKED): //sets the day being viewed to Friday
  		{
  		    week[myDay]= (txtbox->DataGet());
  		    Status("Friday");
		 	DispBox(Friday);
			break;
		}
		case SIGNAL(IDB_SAT, PSF_CLICKED): //sets the day being viewed to Saturday
  		{
  		    week[myDay]= (txtbox->DataGet());
  		    Status("Saturday");
		 	DispBox(Saturday);
			break;
		}
		case HM_SYS_CLOSE: //when the application is exited save all the task data
		{
		    Write();
		    break;
		}
		case PM_SIZE:
  		{
			if(!isStartUp)
			{
			    isFullScreen= !isFullScreen; //switch screen size settings
				if(isFullScreen)
				{
				    PegRect r = {8,64,151,210}; //full screen size
				    txtbox->Resize(r);
				}
				else
				{
				    PegRect r = {8,64,151,120}; //half screen size
					txtbox->Resize(r);
				}
			}			
			break;
		}											         
		return 0;
    }
	return CPModuleWindow::Message(Mesg);
}
